package com.ruoyi.system.mapper;

import java.util.List;
import com.ruoyi.system.domain.CpsMeetingEnterpriseTripInfo;

/**
 * cps_meeting_enterprise_trip_info与会企业行程信息Mapper接口
 * 
 * @author ruoyi
 * @date 2024-08-14
 */
public interface CpsMeetingEnterpriseTripInfoMapper 
{
    /**
     * 查询cps_meeting_enterprise_trip_info与会企业行程信息
     * 
     * @param id cps_meeting_enterprise_trip_info与会企业行程信息主键
     * @return cps_meeting_enterprise_trip_info与会企业行程信息
     */
    public CpsMeetingEnterpriseTripInfo selectCpsMeetingEnterpriseTripInfoById(Long id);

    /**
     * 查询cps_meeting_enterprise_trip_info与会企业行程信息列表
     * 
     * @param cpsMeetingEnterpriseTripInfo cps_meeting_enterprise_trip_info与会企业行程信息
     * @return cps_meeting_enterprise_trip_info与会企业行程信息集合
     */
    public List<CpsMeetingEnterpriseTripInfo> selectCpsMeetingEnterpriseTripInfoList(CpsMeetingEnterpriseTripInfo cpsMeetingEnterpriseTripInfo);

    /**
     * 新增cps_meeting_enterprise_trip_info与会企业行程信息
     * 
     * @param cpsMeetingEnterpriseTripInfo cps_meeting_enterprise_trip_info与会企业行程信息
     * @return 结果
     */
    public int insertCpsMeetingEnterpriseTripInfo(CpsMeetingEnterpriseTripInfo cpsMeetingEnterpriseTripInfo);

    /**
     * 修改cps_meeting_enterprise_trip_info与会企业行程信息
     * 
     * @param cpsMeetingEnterpriseTripInfo cps_meeting_enterprise_trip_info与会企业行程信息
     * @return 结果
     */
    public int updateCpsMeetingEnterpriseTripInfo(CpsMeetingEnterpriseTripInfo cpsMeetingEnterpriseTripInfo);

    /**
     * 删除cps_meeting_enterprise_trip_info与会企业行程信息
     * 
     * @param id cps_meeting_enterprise_trip_info与会企业行程信息主键
     * @return 结果
     */
    public int deleteCpsMeetingEnterpriseTripInfoById(Long id);

    /**
     * 批量删除cps_meeting_enterprise_trip_info与会企业行程信息
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteCpsMeetingEnterpriseTripInfoByIds(Long[] ids);
}
